stringtools.format_input_lines_as_regression_test
=================================================

.. autofunction:: abjad.tools.stringtools.format_input_lines_as_regression_test.format_input_lines_as_regression_test
